"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectConfig = void 0;
const tslib_1 = require("tslib");
const typescript_1 = tslib_1.__importDefault(require("typescript"));
const getValidPackageName_1 = require("./inc/getValidPackageName");
class ProjectConfig {
    options;
    logger;
    tsconfigPath;
    constructor(options, logger) {
        this.options = options;
        this.logger = logger;
        this.tsconfigPath = options.configFilePath;
        if (!this.tsconfigPath) {
            logger.error(`current TypeScript API (${typescript_1.default.version}) not compitable with "${require('../package.json').name}"`);
        }
    }
    _packageJsonCache;
    findPackageJson() {
        if (this._packageJsonCache === undefined) {
            this._packageJsonCache = (0, getValidPackageName_1.getValidPackageFile)(this.tsconfigPath);
        }
        return this._packageJsonCache || undefined;
    }
    get packageJson() {
        const pkg = this.findPackageJson();
        if (!pkg) {
            const msg = 'missing package.json, find from ' + this.tsconfigPath;
            this.logger.error(msg);
            throw new Error(msg);
        }
        return pkg;
    }
}
exports.ProjectConfig = ProjectConfig;
//# sourceMappingURL=ProjectConfig.js.map