"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapHeftLogger = exports.getDebug = exports.formatMyDiagnostic = exports.printMyDiagnostic = void 0;
const tslib_1 = require("tslib");
const util_1 = require("util");
const fancy_log_1 = tslib_1.__importDefault(require("fancy-log"));
const node_1 = require("@idlebox/node");
function printMyDiagnostic(node, message, ...args) {
    console.error(formatMyDiagnostic(node, message, ...args));
}
exports.printMyDiagnostic = printMyDiagnostic;
function diagnosticPrinter(logger) {
    return (node, message, ...args) => {
        const pos = node.getSourceFile().getLineAndCharacterOfPosition(node.getStart());
        logger('%s(%s,%s): ' + message, (0, node_1.relativePath)(process.cwd(), node.getSourceFile().fileName), pos.line + 1, pos.character, ...args);
    };
}
function formatMyDiagnostic(node, message, ...args) {
    if (node.getSourceFile()) {
        const pos = node.getSourceFile().getLineAndCharacterOfPosition(node.getStart());
        return (0, util_1.format)('%s(%s,%s): ' + message, (0, node_1.relativePath)(process.cwd(), node.getSourceFile().fileName), pos.line + 1, pos.character, ...args);
    }
    else {
        return (0, util_1.format)('(%s failed get position) ' + message, node, ...args);
    }
}
exports.formatMyDiagnostic = formatMyDiagnostic;
function getDebug(verbose) {
    return {
        debug: verbose ? fancy_log_1.default.info : () => { },
        error: fancy_log_1.default.error,
        log: fancy_log_1.default.info,
        warn: fancy_log_1.default.warn,
        diagnostic: diagnosticPrinter(fancy_log_1.default.info),
    };
}
exports.getDebug = getDebug;
function wrapHeftLogger(logger, verbose) {
    return {
        debug(msg, ...args) {
            if (verbose) {
                logger.terminal.writeLine((0, util_1.format)(msg, ...args));
            }
            else {
                logger.terminal.writeVerboseLine((0, util_1.format)(msg, ...args));
            }
        },
        log(msg, ...args) {
            logger.terminal.writeWarningLine((0, util_1.format)(msg, ...args));
        },
        warn(msg, ...args) {
            logger.terminal.writeWarningLine((0, util_1.format)(msg, ...args));
        },
        error(msg, ...args) {
            logger.terminal.writeErrorLine((0, util_1.format)(msg, ...args));
        },
        diagnostic: diagnosticPrinter((msg, ...args) => {
            logger.terminal.writeLine((0, util_1.format)(msg, ...args));
        }),
    };
}
exports.wrapHeftLogger = wrapHeftLogger;
//# sourceMappingURL=logger.js.map