import ts from 'typescript';
import { IDebug } from './logger';
import { ModuleResolver } from './ModuleResolver';
import type { IScopedLogger } from '@rushstack/heft';
export declare enum EngineKind {
    Heft = 0,
    TTypescript = 1
}
export interface IPublicOptions {
    verbose?: boolean;
    logger?: IScopedLogger;
}
export interface IMutation {
    types: ts.SyntaxKind[];
    method: (node: ts.Node) => ts.Node | void;
}
export interface INotify {
    types: ts.SyntaxKind[];
    method: (node: ts.Node) => boolean | void;
}
export declare abstract class TypescriptTransformPlugin<IOptions extends Record<string, any> = {}> {
    private readonly callee;
    protected isDebug: boolean;
    protected engine: EngineKind;
    protected logger: IDebug;
    protected _program: ts.Program;
    protected context: ts.TransformationContext;
    pluginOptions: Readonly<IOptions & IPublicOptions>;
    protected compilerHost: ts.CompilerHost;
    private readonly _mutations;
    private readonly _notifies;
    private _compilerOptions?;
    private configurePhase;
    protected resolver: ModuleResolver;
    protected transformToplevelNodes?(node: ts.Node): ts.Node | ts.Node[] | undefined;
    protected configure?(context: ts.TransformationContext, options: ts.CompilerOptions): void;
    constructor();
    private _pluginName?;
    get pluginName(): string;
    protected get program(): ts.Program;
    get compilerOptions(): ts.CompilerOptions;
    forkProgram(overrideOptions?: Partial<ts.CompilerOptions>, filter?: (files: readonly string[]) => string[]): ts.Program;
    plugin(program: ts.Program, options: IOptions & IPublicOptions): (context: ts.TransformationContext) => ts.Transformer<ts.SourceFile>;
    private _onSubstituteNode;
    private _onEmitNode;
    protected registerNotifycation<T extends ts.Node>(kinds: ts.SyntaxKind[], func: (this: this, node: T) => boolean | void): void;
    protected registerMutation<T extends ts.Node>(kinds: ts.SyntaxKind[], func: (this: this, node: T) => ts.Node | ts.Node[] | void): void;
    private receiveContext;
    private transformer;
}
//# sourceMappingURL=pluginClass.d.ts.map