"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReplacementSet = exports.NodeReplacer = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@idlebox/common");
const typescript_1 = tslib_1.__importDefault(require("typescript"));
const util_1 = require("./util");
class NodeReplacer {
    constructor() {
        if (this.replace !== NodeReplacer.prototype.replace) {
            throw new TypeError('can not override final method NodeReplacer::replace()');
        }
    }
    replace(node, context, logger) {
        const result = this._replace(node, context, logger);
        if (!result)
            return result;
        if ((0, util_1.isAstNode)(result)) {
            (0, util_1.linkParentNode)(result, node);
            return result;
        }
        else if (Array.isArray(result) && (result.length === 0 || (0, util_1.isAstNode)(result[0]))) {
            for (const element of result) {
                (0, util_1.linkParentNode)(element, node);
            }
        }
        else {
            logger.warn('[transform/replacer] unknown return value from replace() method');
        }
        return result;
    }
}
exports.NodeReplacer = NodeReplacer;
class ReplacementSet {
    context;
    logger;
    list = [];
    constructor(context, logger) {
        this.context = context;
        this.logger = logger;
    }
    execute(node) {
        // this.logger.debug('ReplacementSet:');
        for (const item of this.list) {
            // this.logger.debug('  - %s', item.constructor.name);
            if (item.check(node, this.logger)) {
                const newNode = item.replace(node, this.context, this.logger);
                if (newNode)
                    node = newNode;
            }
        }
        return node;
    }
    push(replacer) {
        this.list.push(replacer);
    }
    get syntaxKinds() {
        const uniq = new Set();
        for (const { kinds } of this.list) {
            for (const kind of kinds) {
                uniq.add(kind);
            }
        }
        return [...uniq.values()];
    }
}
tslib_1.__decorate([
    common_1.bindThis,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Object)
], ReplacementSet.prototype, "execute", null);
tslib_1.__decorate([
    common_1.bindThis,
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [NodeReplacer]),
    tslib_1.__metadata("design:returntype", void 0)
], ReplacementSet.prototype, "push", null);
exports.ReplacementSet = ReplacementSet;
//# sourceMappingURL=testReplace.js.map