"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.linkParentNode = exports.isAstNode = exports.tryGetSourceFile = exports.isEsModule = exports.isImportExportFrom = exports.extensionIsKindOfScriptFile = exports.nameToString = exports.idToString = void 0;
const tslib_1 = require("tslib");
const path_1 = require("path");
const typescript_1 = tslib_1.__importStar(require("typescript"));
const logger_1 = require("./logger");
function idToString(id) {
    return id.escapedText.toString();
}
exports.idToString = idToString;
function nameToString(name) {
    if (typescript_1.default.isStringLiteral(name)) {
        return name.text;
    }
    else {
        return name.escapedText.toString();
    }
}
exports.nameToString = nameToString;
function extensionIsKindOfScriptFile(f) {
    const e = (0, path_1.extname)(f).toLowerCase();
    return e === '.js' || e === '.jsx' || e === '.ts' || e === '.tsx' || e === '.cjs' || e === '.mjs';
}
exports.extensionIsKindOfScriptFile = extensionIsKindOfScriptFile;
function isImportExportFrom(node) {
    if (!typescript_1.default.isImportDeclaration(node) && !typescript_1.default.isExportDeclaration(node)) {
        // not "import .. from" or "export .. from"
        return false;
    }
    const moduleSpecifier = node.moduleSpecifier;
    if (!moduleSpecifier) {
        // simple "export xxx" (not from)
        return false;
    }
    if (!(moduleSpecifier.kind === typescript_1.default.SyntaxKind.StringLiteral || typescript_1.default.isStringLiteral(moduleSpecifier))) {
        throw new SyntaxError((0, logger_1.formatMyDiagnostic)(node, 'invalid import/export moduleSpecifier'));
    }
    return true;
}
exports.isImportExportFrom = isImportExportFrom;
function isEsModule(module) {
    const mdl = module;
    return mdl >= typescript_1.default.ModuleKind.ES2015 && mdl <= typescript_1.default.ModuleKind.ESNext;
}
exports.isEsModule = isEsModule;
function tryGetSourceFile(node) {
    if (typescript_1.default.isSourceFile(node)) {
        return node;
    }
    if (node.parent) {
        const r = tryGetSourceFile(node.parent);
        if (r) {
            return r;
        }
    }
    const original = typescript_1.default.getOriginalNode(node);
    if (original && node !== original) {
        const r = tryGetSourceFile(original);
        if (r) {
            return r;
        }
    }
    return undefined;
}
exports.tryGetSourceFile = tryGetSourceFile;
function isAstNode(node) {
    if (node && node.kind >= typescript_1.default.SyntaxKind.FirstNode) {
        return true;
    }
    return false;
}
exports.isAstNode = isAstNode;
function linkParentNode(element, parent) {
    if (!parent)
        return;
    if (!element.parent) {
        const original = (0, typescript_1.getOriginalNode)(parent);
        if (original && original !== parent) {
            parent = original;
        }
        Object.assign(element, { parent: parent.parent });
    }
}
exports.linkParentNode = linkParentNode;
//# sourceMappingURL=util.js.map